@@ -781,7 +781,9 @@ retry_replication:
 				}
 				else if (status == STATUS_ERROR)
 				{
-					goto retry_replication;
+					CommandCounterIncrement();
+					continue;
+					/* goto retry_replication; */
 				}
 				else if (status == STATUS_DEADLOCK_DETECT)
 				{
